@@ -20,11 +20,15 @@
 #' open_url(session = session, "https://r-project.org")
 #'
 #' @export
-open_url <- function(url, timeout = 60, session = NULL) {
+open_url <- function(url, timeout = NULL, session = NULL) {
   check_string(url)
-  check_number_decimal(timeout)
+  check_number_decimal(timeout, allow_null = TRUE)
   check_class(session, "selenider_session", allow_null = TRUE)
 
+  if (is.null(timeout)) {
+    timeout <- if (on_ci()) 60 * 5 else 60
+  }
+
   if (is.null(session)) {
     session <- get_session(.env = caller_env())
   }
@@ -58,6 +62,8 @@ open_url <- function(url, timeout = 60, session = NULL) {
 #' browsing history.
 #'
 #' @param timeout The maximum time to wait for the page to load, in seconds.
+#'   This defaults to 60, unless in a Github Action, in which case it defaults
+#'   to 5 minutes.
 #' @param session A `selenider_session` object. If not specified, the global
 #'   session object (the result of [get_session()]) is used.
 #'
@@ -78,10 +84,14 @@ open_url <- function(url, timeout = 60, session = NULL) {
 #' forward()
 #'
 #' @export
-back <- function(timeout = 60, session = NULL) {
-  check_number_decimal(timeout)
+back <- function(timeout = NULL, session = NULL) {
+  check_number_decimal(timeout, allow_null = TRUE)
   check_class(session, "selenider_session", allow_null = TRUE)
 
+  if (is.null(timeout)) {
+    timeout <- if (on_ci()) 60 * 5 else 60
+  }
+
   if (is.null(session)) {
     session <- get_session(.env = caller_env())
   }
@@ -117,10 +127,14 @@ back <- function(timeout = 60, session = NULL) {
 #' @rdname back
 #'
 #' @export
-forward <- function(timeout = 60, session = NULL) {
-  check_number_decimal(timeout)
+forward <- function(timeout = NULL, session = NULL) {
+  check_number_decimal(timeout, allow_null = TRUE)
   check_class(session, "selenider_session", allow_null = TRUE)
 
+  if (is.null(timeout)) {
+    timeout <- if (on_ci()) 60 * 5 else 60
+  }
+
   if (is.null(session)) {
     session <- get_session(.env = caller_env())
   }
@@ -172,10 +186,14 @@ forward <- function(timeout = 60, session = NULL) {
 #' reload()
 #'
 #' @export
-reload <- function(timeout = 60, session = NULL) {
-  check_number_decimal(timeout)
+reload <- function(timeout = NULL, session = NULL) {
+  check_number_decimal(timeout, allow_null = TRUE)
   check_class(session, "selenider_session", allow_null = TRUE)
 
+  if (is.null(timeout)) {
+    timeout <- if (on_ci()) 60 * 5 else 60
+  }
+
   if (is.null(session)) {
     session <- get_session(.env = caller_env())
   }
@@ -204,6 +222,80 @@ reload <- function(timeout = 60, session = NULL) {
 #' @export
 refresh <- reload
 
+#' Scroll along the page
+#'
+#' @description
+#' `scroll_to()` scrolls the page to the specified coordinates.
+#'
+#' `scroll_by()` scrolls the page by the specified amount.
+#'
+#' @param top The vertical scroll position/offset, in pixels.
+#' @param left The horizontal scroll position/offset, in pixels.
+#' @param session A `selenider_session` object. If not specified, the global
+#'   session object (the result of [get_session()]) is used.
+#'
+#' @family global actions
+#'
+#' @examplesIf selenider::selenider_available()
+#' session <- selenider_session()
+#'
+#' open_url("https://r-project.org")
+#'
+#' scroll_to(100, 100)
+#'
+#' # Scrolls an additional 100 pixels down
+#' scroll_by(100)
+#'
+#' @export
+scroll_to <- function(top = 0, left = 0, session = NULL) {
+  check_number_whole(top)
+  check_number_whole(left)
+  check_class(session, "selenider_session", allow_null = TRUE)
+
+  if (is.null(session)) {
+    session <- get_session(.env = caller_env())
+  }
+
+  driver <- session$driver
+
+  execute_js_expr_internal(
+    paste0("window.scrollTo(", left, ",", top, ");"),
+    session = session$session,
+    driver = driver
+  )
+}
+
+#' @rdname scroll_to
+#'
+#' @export
+scroll_by <- function(top = 0, left = 0, session = NULL) {
+  check_number_whole(top)
+  check_number_whole(left)
+  check_class(session, "selenider_session", allow_null = TRUE)
+
+  if (is.null(session)) {
+    session <- get_session(.env = caller_env())
+  }
+
+  driver <- session$driver
+
+  if (session$session == "chromote") {
+    driver$Input$dispatchMouseEvent(
+      type = "mouseWheel",
+      x = 0,
+      y = 0,
+      deltaX = left,
+      deltaY = top,
+    )
+  } else {
+    execute_js_expr_internal(
+      paste0("window.scrollBy(", left, ",", top, ");"),
+      session = session$session,
+      driver = driver
+    )
+  }
+}
+
 #' Take a screenshot of the current page
 #'
 #' Take a screenshot of the current session state, saving this image to a file.
